@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, List, Union
 
-from typing_extensions import Literal, NotRequired, TypedDict
+from typing_extensions import Literal, NotRequired, TypedDict, final
 
 if TYPE_CHECKING:
     from ..resources import EmojiData
@@ -16,6 +16,7 @@ __all__ = (
 # https://discord.com/developers/docs/interactions/message-components#action-rows
 
 
+@final
 class ActionRowData(TypedDict):
     type: Literal[1]
     components: NotRequired[List[Union[ButtonComponentData, SelectMenuComponentData]]]
@@ -26,6 +27,7 @@ class ActionRowData(TypedDict):
 
 # The whole button object itself is split into NonLinkButtonComponent and
 # LinkButtonComponent because link buttons need to have the link-style.
+@final
 class NonLinkButtonComponentData(TypedDict):
     type: Literal[2]
     style: Literal[1, 2, 3, 4]
@@ -35,6 +37,7 @@ class NonLinkButtonComponentData(TypedDict):
     disabled: NotRequired[bool]
 
 
+@final
 class LinkButtonComponentData(TypedDict):
     type: Literal[2]
     style: Literal[5]
@@ -50,6 +53,7 @@ ButtonComponentData = Union[NonLinkButtonComponentData, LinkButtonComponentData]
 # https://discord.com/developers/docs/interactions/message-components#select-menu-object-select-menu-structure
 
 
+@final
 class SelectMenuComponentData(TypedDict):
     type: Literal[3]
     custom_id: str
@@ -63,6 +67,7 @@ class SelectMenuComponentData(TypedDict):
 # https://discord.com/developers/docs/interactions/message-components#select-menu-object-select-option-structure
 
 
+@final
 class SelectMenuOptionData(TypedDict):
     label: str
     value: str
@@ -74,6 +79,7 @@ class SelectMenuOptionData(TypedDict):
 # https://discord.com/developers/docs/interactions/message-components#text-inputs-text-input-structure
 
 
+@final
 class TextInputComponentData(TypedDict):
     type: Literal[4]
     custom_id: str
